@@ -4,7 +4,7 @@ from __future__ import unicode_literals
 from collections import defaultdict
 
 from trytond.model import ModelSQL, ModelView, Workflow, fields
-from trytond.pyson import Eval, If, Bool, Id
+from trytond.pyson import Eval, If, Bool
 from trytond.pool import Pool
 from trytond.transaction import Transaction
 from trytond import backend
@@ -109,14 +109,10 @@ class Complaint(Workflow, ModelSQL, ModelView):
                     'invisible': ~Eval('state').in_(['draft']),
                     },
                 'approve': {
-                    'invisible': (~Eval('state').in_(['waiting'])
-                        & Eval('context', {}).get('groups', []).contains(
-                            Id('sale', 'group_sale_admin'))),
+                    'invisible': ~Eval('state').in_(['waiting']),
                     },
                 'reject': {
-                    'invisible': (~Eval('state').in_(['waiting'])
-                        & Eval('context', {}).get('groups', []).contains(
-                            Id('sale', 'group_sale_admin'))),
+                    'invisible': ~Eval('state').in_(['waiting']),
                     },
                 'process': {
                     'invisible': ~Eval('state').in_(['approved']),
@@ -368,7 +364,7 @@ class Action(ModelSQL, ModelView):
 
     @fields.depends('complaint')
     def on_change_with_unit(self, name=None):
-        if self.complaint.origin_model == 'sale.line':
+        if self.complaint and self.complaint.origin_model == 'sale.line':
             return self.complaint.origin.unit.id
 
     @fields.depends('complaint')
@@ -438,22 +434,22 @@ class Action(ModelSQL, ModelView):
                 invoice_line = self.complaint.origin
                 invoice = invoice_line.invoice
                 invoice_lines = [invoice_line]
-            values = invoice._credit()
-            lines_values = []
+            credit_note = invoice._credit()
+            credit_lines = []
             for invoice_line in invoice_lines:
                 credit_line = invoice_line._credit()
-                lines_values.append(credit_line)
+                credit_lines.append(credit_line)
                 # Remove product as it is not a return
-                credit_line.pop('product', None)
-                credit_line['origin'] = str(self.complaint)
+                credit_line.product = None
+                credit_line.origin = self.complaint
             if isinstance(self.complaint.origin, Line):
                 if self.quantity is not None:
-                    lines_values[0]['quantity'] = -self.quantity
+                    credit_lines[0].quantity = -self.quantity
                 if self.unit_price is not None:
-                    lines_values[0]['unit_price'] = self.unit_price
-            values['lines'] = [('create', lines_values)]
-            del values['taxes']
-            credit_note, = Invoice.create([values])
+                    credit_lines[0].unit_price = self.unit_price
+            credit_note.lines = credit_lines
+            credit_note.taxes = None
+            credit_note.save()
             Invoice.update_taxes([credit_note])
         else:
             return
